summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--officecfg/registry/schema/org/openoffice/Office/Compatibility.xcs2
-rw-r--r--sw/inc/IDocumentSettingAccess.hxx2
-rw-r--r--sw/inc/strings.hrc2
-rw-r--r--sw/inc/viewsh.hxx2
-rw-r--r--sw/qa/extras/odfexport/odfexport2.cxx23
-rw-r--r--sw/source/core/doc/DocumentSettingManager.cxx14
-rw-r--r--sw/source/core/inc/DocumentSettingManager.hxx2
-rw-r--r--sw/source/core/text/porfld.cxx2
-rw-r--r--sw/source/core/view/viewsh.cxx6
-rw-r--r--sw/source/filter/ww8/ww8par.cxx2
-rw-r--r--sw/source/ui/config/optcomp.cxx8
-rw-r--r--sw/source/uibase/uno/SwXDocumentSettings.cxx12
-rw-r--r--writerfilter/source/dmapper/DomainMapper.cxx3
-rw-r--r--writerfilter/source/filter/WriterFilter.cxx2
14 files changed, 40 insertions, 42 deletions
diff --git a/officecfg/registry/schema/org/openoffice/Office/Compatibility.xcs b/officecfg/registry/schema/org/openoffice/Office/Compatibility.xcs
index 118a4c30108e..8d5f1e172918 100644
--- a/officecfg/registry/schema/org/openoffice/Office/Compatibility.xcs
+++ b/officecfg/registry/schema/org/openoffice/Office/Compatibility.xcs
@@ -134,7 +134,7 @@
</info>
<value>false</value>
</prop>
- <prop oor:name="NoSpaceAfterHangingFootnoteNumbering" oor:type="xs:boolean" oor:nillable="false">
+ <prop oor:name="NoGapAfterNoteNumber" oor:type="xs:boolean" oor:nillable="false">
<info>
<desc>Do not add an extra space after number in footnotes with hanging first line</desc>
</info>
diff --git a/sw/inc/IDocumentSettingAccess.hxx b/sw/inc/IDocumentSettingAccess.hxx
index c58facf04d3d..74b123dc462e 100644
--- a/sw/inc/IDocumentSettingAccess.hxx
+++ b/sw/inc/IDocumentSettingAccess.hxx
@@ -59,7 +59,7 @@ enum class DocumentSettingId
TREAT_SINGLE_COLUMN_BREAK_AS_PAGE_BREAK,
DO_NOT_RESET_PARA_ATTRS_FOR_NUM_FONT,
// tdf#159382: MS Word compatible handling of space between footnote number and text
- NO_SPACE_AFTER_HANGING_FOOTNOTE_NUMBER,
+ NO_GAP_AFTER_NOTE_NUMBER,
DO_NOT_CAPTURE_DRAW_OBJS_ON_PAGE,
TABLE_ROW_KEEP,
diff --git a/sw/inc/strings.hrc b/sw/inc/strings.hrc
index 3637dfe1db56..2986e03b9a85 100644
--- a/sw/inc/strings.hrc
+++ b/sw/inc/strings.hrc
@@ -1489,7 +1489,7 @@
#define STR_COMPAT_OPT_SUBTRACTFLYSANCHOREDATFLYS NC_("STR_COMPAT_OPT_SUBTRACTFLYSANCHOREDATFLYS", "Tolerate white lines that may appear in PDF page backgrounds")
#define STR_COMPAT_OPT_EMPTYDBFIELDHIDESPARA NC_("STR_COMPAT_OPT_EMPTYDBFIELDHIDESPARA", "Hide paragraphs of database fields (e.g., mail merge) with an empty value")
#define STR_COMPAT_OPT_USEVARIABLEWIDTHNBSP NC_("STR_COMPAT_OPT_USEVARIABLEWIDTHNBSP", "Render non-breaking spaces (NBSP) as standard-space-width (off for fixed size)")
-#define STR_COMPAT_OPT_NOSPACEAFTERHANGINGFOOTNOTENUMBERING NC_("STR_COMPAT_OPT_NOSPACEAFTERHANGINGFOOTNOTENUMBERING", "Do not add an extra space after number in footnotes with hanging first line")
+#define STR_COMPAT_OPT_NOGAPAFTERNOTENUMBER NC_("STR_COMPAT_OPT_NOGAPAFTERNOTENUMBER", "Do not add an extra space after number in footnotes / endnotes with hanging first line")
#endif
diff --git a/sw/inc/viewsh.hxx b/sw/inc/viewsh.hxx
index b4fb99df081a..aa3999efbf7f 100644
--- a/sw/inc/viewsh.hxx
+++ b/sw/inc/viewsh.hxx
@@ -443,7 +443,7 @@ public:
void SetEmptyDbFieldHidesPara(bool bEmptyDbFieldHidesPara);
- void SetNoSpaceAfterHangingFootnoteNumber(bool bNew);
+ void SetNoGapAfterNoteNumber(bool bNew);
// DOCUMENT COMPATIBILITY FLAGS END
diff --git a/sw/source/core/doc/DocumentSettingManager.cxx b/sw/source/core/doc/DocumentSettingManager.cxx
index 3c29d5de2538..00b9e598450a 100644
--- a/sw/source/core/doc/DocumentSettingManager.cxx
+++ b/sw/source/core/doc/DocumentSettingManager.cxx
@@ -136,7 +136,7 @@ sw::DocumentSettingManager::DocumentSettingManager(SwDoc &rDoc)
mbSubtractFlys = aOptions.get(u"SubtractFlysAnchoredAtFlys"_ustr);
mbEmptyDbFieldHidesPara = aOptions.get(u"EmptyDbFieldHidesPara"_ustr);
mbUseVariableWidthNBSP = aOptions.get(u"UseVariableWidthNBSP"_ustr);
- mbNoSpaceAfterHangingFootnoteNumbering = aOptions.get(u"NoSpaceAfterHangingFootnoteNumbering"_ustr);
+ mbNoGapAfterNoteNumber = aOptions.get(u"NoGapAfterNoteNumber"_ustr);
}
else
{
@@ -191,7 +191,7 @@ bool sw::DocumentSettingManager::get(/*[in]*/ DocumentSettingId id) const
case DocumentSettingId::CONSIDER_WRAP_ON_OBJECT_POSITION: return mbConsiderWrapOnObjPos;
case DocumentSettingId::DO_NOT_JUSTIFY_LINES_WITH_MANUAL_BREAK: return mbDoNotJustifyLinesWithManualBreak;
case DocumentSettingId::IGNORE_FIRST_LINE_INDENT_IN_NUMBERING: return mbIgnoreFirstLineIndentInNumbering;
- case DocumentSettingId::NO_SPACE_AFTER_HANGING_FOOTNOTE_NUMBER: return mbNoSpaceAfterHangingFootnoteNumbering;
+ case DocumentSettingId::NO_GAP_AFTER_NOTE_NUMBER: return mbNoGapAfterNoteNumber;
case DocumentSettingId::TABLE_ROW_KEEP: return mbTableRowKeep;
case DocumentSettingId::IGNORE_TABS_AND_BLANKS_FOR_LINE_CALCULATION: return mbIgnoreTabsAndBlanksForLineCalculation;
case DocumentSettingId::DO_NOT_CAPTURE_DRAW_OBJS_ON_PAGE: return mbDoNotCaptureDrawObjsOnPage;
@@ -337,8 +337,8 @@ void sw::DocumentSettingManager::set(/*[in]*/ DocumentSettingId id, /*[in]*/ boo
case DocumentSettingId::IGNORE_FIRST_LINE_INDENT_IN_NUMBERING:
mbIgnoreFirstLineIndentInNumbering = value;
break;
- case DocumentSettingId::NO_SPACE_AFTER_HANGING_FOOTNOTE_NUMBER:
- mbNoSpaceAfterHangingFootnoteNumbering = value;
+ case DocumentSettingId::NO_GAP_AFTER_NOTE_NUMBER:
+ mbNoGapAfterNoteNumber = value;
break;
case DocumentSettingId::TABLE_ROW_KEEP:
@@ -700,7 +700,7 @@ void sw::DocumentSettingManager::ReplaceCompatibilityOptions(const DocumentSetti
mbStylesNoDefault = rSource.mbStylesNoDefault;
mbOldNumbering = rSource.mbOldNumbering;
mbIgnoreFirstLineIndentInNumbering = rSource.mbIgnoreFirstLineIndentInNumbering;
- mbNoSpaceAfterHangingFootnoteNumbering = rSource.mbNoSpaceAfterHangingFootnoteNumbering;
+ mbNoGapAfterNoteNumber = rSource.mbNoGapAfterNoteNumber;
mbDoNotJustifyLinesWithManualBreak = rSource.mbDoNotJustifyLinesWithManualBreak;
mbDoNotResetParaAttrsForNumFont = rSource.mbDoNotResetParaAttrsForNumFont;
mbTableRowKeep = rSource.mbTableRowKeep;
@@ -884,10 +884,10 @@ void sw::DocumentSettingManager::dumpAsXml(xmlTextWriterPtr pWriter) const
BAD_CAST(OString::boolean(mbIgnoreFirstLineIndentInNumbering).getStr()));
(void)xmlTextWriterEndElement(pWriter);
- (void)xmlTextWriterStartElement(pWriter, BAD_CAST("mbNoSpaceAfterHangingFootnoteNumbering"));
+ (void)xmlTextWriterStartElement(pWriter, BAD_CAST("mbNoGapAfterNoteNumber"));
(void)xmlTextWriterWriteAttribute(
pWriter, BAD_CAST("value"),
- BAD_CAST(OString::boolean(mbNoSpaceAfterHangingFootnoteNumbering).getStr()));
+ BAD_CAST(OString::boolean(mbNoGapAfterNoteNumber).getStr()));
(void)xmlTextWriterEndElement(pWriter);
(void)xmlTextWriterStartElement(pWriter, BAD_CAST("mbDoNotJustifyLinesWithManualBreak"));
diff --git a/sw/source/core/inc/DocumentSettingManager.hxx b/sw/source/core/inc/DocumentSettingManager.hxx
index 38bd64818dd1..561479a5f0aa 100644
--- a/sw/source/core/inc/DocumentSettingManager.hxx
+++ b/sw/source/core/inc/DocumentSettingManager.hxx
@@ -132,7 +132,7 @@ class DocumentSettingManager final :
// non-ui-compatibility flags:
bool mbOldNumbering : 1;
bool mbIgnoreFirstLineIndentInNumbering : 1; // #i47448#
- bool mbNoSpaceAfterHangingFootnoteNumbering : 1 = false; // tdf#159382
+ bool mbNoGapAfterNoteNumber : 1 = false; // tdf#159382
bool mbDoNotJustifyLinesWithManualBreak : 1; // #i49277#
bool mbDoNotResetParaAttrsForNumFont : 1; // #i53199#
bool mbTableRowKeep : 1;
diff --git a/sw/source/core/text/porfld.cxx b/sw/source/core/text/porfld.cxx
index 4718fcfbc169..d2ae4be00d1b 100644
--- a/sw/source/core/text/porfld.cxx
+++ b/sw/source/core/text/porfld.cxx
@@ -607,7 +607,7 @@ bool SwNumberPortion::Format( SwTextFormatInfo &rInf )
!IsFootnoteNumPortion()) ||
// tdf#159382
(IsFootnoteNumPortion() &&
- rInf.GetTextFrame()->GetDoc().getIDocumentSettingAccess().get(DocumentSettingId::NO_SPACE_AFTER_HANGING_FOOTNOTE_NUMBER)))
+ rInf.GetTextFrame()->GetDoc().getIDocumentSettingAccess().get(DocumentSettingId::NO_GAP_AFTER_NOTE_NUMBER)))
{
nDiff = rInf.Left()
+ rInf.GetTextFrame()->GetTextNodeForParaProps()->
diff --git a/sw/source/core/view/viewsh.cxx b/sw/source/core/view/viewsh.cxx
index 6dfed8d075a6..5fac88dac7a6 100644
--- a/sw/source/core/view/viewsh.cxx
+++ b/sw/source/core/view/viewsh.cxx
@@ -1047,13 +1047,13 @@ void SwViewShell::SetEmptyDbFieldHidesPara(bool bEmptyDbFieldHidesPara)
EndAction();
}
-void SwViewShell::SetNoSpaceAfterHangingFootnoteNumber(bool bNew)
+void SwViewShell::SetNoGapAfterNoteNumber(bool bNew)
{
IDocumentSettingAccess& rIDSA = getIDocumentSettingAccess();
- if (rIDSA.get(DocumentSettingId::NO_SPACE_AFTER_HANGING_FOOTNOTE_NUMBER) != bNew)
+ if (rIDSA.get(DocumentSettingId::NO_GAP_AFTER_NOTE_NUMBER) != bNew)
{
SwWait aWait(*GetDoc()->GetDocShell(), true);
- rIDSA.set(DocumentSettingId::NO_SPACE_AFTER_HANGING_FOOTNOTE_NUMBER, bNew);
+ rIDSA.set(DocumentSettingId::NO_GAP_AFTER_NOTE_NUMBER, bNew);
const SwInvalidateFlags nInv = SwInvalidateFlags::Size | SwInvalidateFlags::Pos | SwInvalidateFlags::PrtArea;
lcl_InvalidateAllContent(*this, nInv);
}
diff --git a/sw/source/filter/ww8/ww8par.cxx b/sw/source/filter/ww8/ww8par.cxx
index 97c0a808813b..73c9b8a6b867 100644
--- a/sw/source/filter/ww8/ww8par.cxx
+++ b/sw/source/filter/ww8/ww8par.cxx
@@ -1911,7 +1911,7 @@ void SwWW8ImplReader::ImportDop()
m_rDoc.getIDocumentSettingAccess().set(DocumentSettingId::ADD_EXT_LEADING, !m_xWDop->fNoLeading);
m_rDoc.getIDocumentSettingAccess().set(DocumentSettingId::OLD_NUMBERING, false);
m_rDoc.getIDocumentSettingAccess().set(DocumentSettingId::IGNORE_FIRST_LINE_INDENT_IN_NUMBERING, false); // #i47448#
- m_rDoc.getIDocumentSettingAccess().set(DocumentSettingId::NO_SPACE_AFTER_HANGING_FOOTNOTE_NUMBER, true); // tdf#159382
+ m_rDoc.getIDocumentSettingAccess().set(DocumentSettingId::NO_GAP_AFTER_NOTE_NUMBER, true); // tdf#159382
m_rDoc.getIDocumentSettingAccess().set(DocumentSettingId::DO_NOT_JUSTIFY_LINES_WITH_MANUAL_BREAK, !m_xWDop->fExpShRtn); // #i49277#, #i56856#
m_rDoc.getIDocumentSettingAccess().set(DocumentSettingId::DO_NOT_RESET_PARA_ATTRS_FOR_NUM_FONT, false); // #i53199#
m_rDoc.getIDocumentSettingAccess().set(DocumentSettingId::OLD_LINE_SPACING, false);
diff --git a/sw/source/ui/config/optcomp.cxx b/sw/source/ui/config/optcomp.cxx
index 1c70a9ca3b55..783dddb57e49 100644
--- a/sw/source/ui/config/optcomp.cxx
+++ b/sw/source/ui/config/optcomp.cxx
@@ -60,7 +60,7 @@ constexpr std::pair<OUString, TranslateId> options_list[]{
{ u"SubtractFlysAnchoredAtFlys"_ustr, STR_COMPAT_OPT_SUBTRACTFLYSANCHOREDATFLYS },
{ u"EmptyDbFieldHidesPara"_ustr, STR_COMPAT_OPT_EMPTYDBFIELDHIDESPARA },
{ u"UseVariableWidthNBSP"_ustr, STR_COMPAT_OPT_USEVARIABLEWIDTHNBSP },
- { u"NoSpaceAfterHangingFootnoteNumbering"_ustr, STR_COMPAT_OPT_NOSPACEAFTERHANGINGFOOTNOTENUMBERING },
+ { u"NoGapAfterNoteNumber"_ustr, STR_COMPAT_OPT_NOGAPAFTERNOTENUMBER },
};
// DocumentSettingId, negate?
@@ -82,7 +82,7 @@ std::pair<DocumentSettingId, bool> DocumentSettingForOption(const OUString& opti
{ u"SubtractFlysAnchoredAtFlys"_ustr, { DocumentSettingId::SUBTRACT_FLYS, false } },
{ u"EmptyDbFieldHidesPara"_ustr, { DocumentSettingId::EMPTY_DB_FIELD_HIDES_PARA, false } },
{ u"UseVariableWidthNBSP"_ustr, { DocumentSettingId::USE_VARIABLE_WIDTH_NBSP, false } },
- { u"NoSpaceAfterHangingFootnoteNumbering"_ustr, { DocumentSettingId::NO_SPACE_AFTER_HANGING_FOOTNOTE_NUMBER, false } },
+ { u"NoGapAfterNoteNumber"_ustr, { DocumentSettingId::NO_GAP_AFTER_NOTE_NUMBER, false } },
// { u"AddTableLineSpacing"_ustr, { DocumentSettingId::ADD_PARA_LINE_SPACING_TO_TABLE_CELLS, false } },
};
return map.at(option);
@@ -303,8 +303,8 @@ bool SwCompatibilityOptPage::FillItemSet( SfxItemSet* )
.set(DocumentSettingId::USE_VARIABLE_WIDTH_NBSP, bChecked);
break;
- case DocumentSettingId::NO_SPACE_AFTER_HANGING_FOOTNOTE_NUMBER:
- m_pWrtShell->SetNoSpaceAfterHangingFootnoteNumber(bChecked);
+ case DocumentSettingId::NO_GAP_AFTER_NOTE_NUMBER:
+ m_pWrtShell->SetNoGapAfterNoteNumber(bChecked);
break;
default:
diff --git a/sw/source/uibase/uno/SwXDocumentSettings.cxx b/sw/source/uibase/uno/SwXDocumentSettings.cxx
index 2f9c480f3982..e3c142122cba 100644
--- a/sw/source/uibase/uno/SwXDocumentSettings.cxx
+++ b/sw/source/uibase/uno/SwXDocumentSettings.cxx
@@ -101,7 +101,7 @@ enum SwDocumentSettingsPropertyHandles
HANDLE_CHANGES_PASSWORD,
HANDLE_CONSIDER_WRAP_ON_OBJPOS,
HANDLE_IGNORE_FIRST_LINE_INDENT_IN_NUMBERING,
- HANDLE_NO_SPACE_AFTER_HANGING_FOOTNOTE_NUMBER,
+ HANDLE_NO_GAP_AFTER_NOTE_NUMBER,
HANDLE_DO_NOT_JUSTIFY_LINES_WITH_MANUAL_BREAK,
HANDLE_DO_NOT_RESET_PARA_ATTRS_FOR_NUM_FONT,
HANDLE_TABLE_ROW_KEEP,
@@ -206,7 +206,7 @@ static rtl::Reference<MasterPropertySetInfo> lcl_createSettingsInfo()
{ OUString("RedlineProtectionKey"), HANDLE_CHANGES_PASSWORD, cppu::UnoType< cppu::UnoSequenceType<sal_Int8> >::get(), 0},
{ OUString("ConsiderTextWrapOnObjPos"), HANDLE_CONSIDER_WRAP_ON_OBJPOS, cppu::UnoType<bool>::get(), 0},
{ OUString("IgnoreFirstLineIndentInNumbering"), HANDLE_IGNORE_FIRST_LINE_INDENT_IN_NUMBERING, cppu::UnoType<bool>::get(), 0},
- { u"NoSpaceAfterHangingFootnoteNumbering"_ustr, HANDLE_NO_SPACE_AFTER_HANGING_FOOTNOTE_NUMBER, cppu::UnoType<bool>::get(), 0},
+ { u"NoGapAfterNoteNumber"_ustr, HANDLE_NO_GAP_AFTER_NOTE_NUMBER, cppu::UnoType<bool>::get(), 0},
{ OUString("DoNotJustifyLinesWithManualBreak"), HANDLE_DO_NOT_JUSTIFY_LINES_WITH_MANUAL_BREAK, cppu::UnoType<bool>::get(), 0},
{ OUString("DoNotResetParaAttrsForNumFont"), HANDLE_DO_NOT_RESET_PARA_ATTRS_FOR_NUM_FONT, cppu::UnoType<bool>::get(), 0},
{ OUString("TableRowKeep"), HANDLE_TABLE_ROW_KEEP, cppu::UnoType<bool>::get(), 0},
@@ -701,10 +701,10 @@ void SwXDocumentSettings::_setSingleValue( const comphelper::PropertyInfo & rInf
mpDoc->getIDocumentSettingAccess().set(DocumentSettingId::IGNORE_FIRST_LINE_INDENT_IN_NUMBERING, bTmp);
}
break;
- case HANDLE_NO_SPACE_AFTER_HANGING_FOOTNOTE_NUMBER:
+ case HANDLE_NO_GAP_AFTER_NOTE_NUMBER:
{
bool bTmp = *o3tl::doAccess<bool>(rValue);
- mpDoc->getIDocumentSettingAccess().set(DocumentSettingId::NO_SPACE_AFTER_HANGING_FOOTNOTE_NUMBER, bTmp);
+ mpDoc->getIDocumentSettingAccess().set(DocumentSettingId::NO_GAP_AFTER_NOTE_NUMBER, bTmp);
}
break;
case HANDLE_DO_NOT_JUSTIFY_LINES_WITH_MANUAL_BREAK:
@@ -1387,9 +1387,9 @@ void SwXDocumentSettings::_getSingleValue( const comphelper::PropertyInfo & rInf
rValue <<= mpDoc->getIDocumentSettingAccess().get(DocumentSettingId::IGNORE_FIRST_LINE_INDENT_IN_NUMBERING);
}
break;
- case HANDLE_NO_SPACE_AFTER_HANGING_FOOTNOTE_NUMBER:
+ case HANDLE_NO_GAP_AFTER_NOTE_NUMBER:
{
- rValue <<= mpDoc->getIDocumentSettingAccess().get(DocumentSettingId::NO_SPACE_AFTER_HANGING_FOOTNOTE_NUMBER);
+ rValue <<= mpDoc->getIDocumentSettingAccess().get(DocumentSettingId::NO_GAP_AFTER_NOTE_NUMBER);
}
break;
case HANDLE_DO_NOT_JUSTIFY_LINES_WITH_MANUAL_BREAK:
diff --git a/writerfilter/source/dmapper/DomainMapper.cxx b/writerfilter/source/dmapper/DomainMapper.cxx
index 35e4e1662c32..ad96d5e3df92 100644
--- a/writerfilter/source/dmapper/DomainMapper.cxx
+++ b/writerfilter/source/dmapper/DomainMapper.cxx
@@ -138,8 +138,7 @@ DomainMapper::DomainMapper( const uno::Reference< uno::XComponentContext >& xCon
m_pImpl->SetDocumentSettingsProperty("FrameAutowidthWithMorePara", uno::Any(true));
m_pImpl->SetDocumentSettingsProperty("FootnoteInColumnToPageEnd", uno::Any(true));
m_pImpl->SetDocumentSettingsProperty("TabAtLeftIndentForParagraphsInList", uno::Any(true));
- m_pImpl->SetDocumentSettingsProperty(u"NoSpaceAfterHangingFootnoteNumbering"_ustr,
- uno::Any(true));
+ m_pImpl->SetDocumentSettingsProperty(u"NoGapAfterNoteNumber"_ustr, uno::Any(true));
// Enable only for new documents, since pasting from clipboard can influence existing doc
m_pImpl->SetDocumentSettingsProperty("NoNumberingShowFollowBy", uno::Any(true));
diff --git a/writerfilter/source/filter/WriterFilter.cxx b/writerfilter/source/filter/WriterFilter.cxx
index 10ea7da5a16f..e7d32c4843e6 100644
--- a/writerfilter/source/filter/WriterFilter.cxx
+++ b/writerfilter/source/filter/WriterFilter.cxx
@@ -304,7 +304,7 @@ void WriterFilter::setTargetDocument(const uno::Reference<lang::XComponent>& xDo
xSettings->setPropertyValue("UseOldNumbering", uno::Any(false));
xSettings->setPropertyValue("IgnoreFirstLineIndentInNumbering", uno::Any(false));
- xSettings->setPropertyValue(u"NoSpaceAfterHangingFootnoteNumbering"_ustr, uno::Any(true));
+ xSettings->setPropertyValue(u"NoGapAfterNoteNumber"_ustr, uno::Any(true));
xSettings->setPropertyValue("DoNotResetParaAttrsForNumFont", uno::Any(false));
xSettings->setPropertyValue("UseFormerLineSpacing", uno::Any(false));
xSettings->setPropertyValue("AddParaSpacingToTableCells", uno::Any(true));
diff --git a/sw/qa/extras/odfexport/odfexport2.cxx b/sw/qa/extras/odfexport/odfexport2.cxx
index fb72969adf64..c88e64c38ee3 100644
--- a/sw/qa/extras/odfexport/odfexport2.cxx
+++ b/sw/qa/extras/odfexport/odfexport2.cxx
@@ -1209,17 +1209,17 @@ CPPUNIT_TEST_FIXTURE(Test, testTdf150408_IsLegal)
CPPUNIT_TEST_FIXTURE(Test, testTdf159382)
{
- // Testing NoSpaceAfterHangingFootnoteNumbering compat option
+ // Testing NoGapAfterNoteNumber compat option
createSwDoc("footnote_spacing_hanging_para.docx");
// 1. Make sure that DOCX import sets NoSpaceAfterHangingFootnoteNumbering option, and creates
// correct layout
{
uno::Reference<lang::XMultiServiceFactory> xFactory(mxComponent, uno::UNO_QUERY_THROW);
uno::Reference<beans::XPropertySet> xSettings(
xFactory->createInstance(u"com.sun.star.document.Settings"_ustr), uno::UNO_QUERY_THROW);
CPPUNIT_ASSERT_EQUAL(uno::Any(true), xSettings->getPropertyValue(
- u"NoSpaceAfterHangingFootnoteNumbering"_ustr));
+ u"NoGapAfterNoteNumber"_ustr));
xmlDocUniquePtr pXmlDoc = parseLayoutDump();
sal_Int32 width
@@ -1232,20 +1232,19 @@ CPPUNIT_TEST_FIXTURE(Test, testTdf159382)
}
saveAndReload(mpFilter);
// 2. Make sure that exported document has NoSpaceAfterHangingFootnoteNumbering option set,
// and has correct layout
{
xmlDocUniquePtr pXmlDoc = parseExport("settings.xml");
assertXPathContent(
pXmlDoc,
- "//config:config-item[@config:name='NoSpaceAfterHangingFootnoteNumbering']"_ostr,
- "true");
+ "//config:config-item[@config:name='NoGapAfterNoteNumber']"_ostr, "true");
uno::Reference<lang::XMultiServiceFactory> xFactory(mxComponent, uno::UNO_QUERY_THROW);
uno::Reference<beans::XPropertySet> xSettings(
xFactory->createInstance(u"com.sun.star.document.Settings"_ustr), uno::UNO_QUERY_THROW);
CPPUNIT_ASSERT_EQUAL(uno::Any(true), xSettings->getPropertyValue(
- u"NoSpaceAfterHangingFootnoteNumbering"_ustr));
+ u"NoGapAfterNoteNumber"_ustr));
pXmlDoc = parseLayoutDump();
sal_Int32 width = getXPath(
@@ -1256,14 +1255,14 @@ CPPUNIT_TEST_FIXTURE(Test, testTdf159382)
}
createSwDoc("footnote_spacing_hanging_para.doc");
// 3. Make sure that DOC import sets NoSpaceAfterHangingFootnoteNumbering option, and creates
// correct layout
{
uno::Reference<lang::XMultiServiceFactory> xFactory(mxComponent, uno::UNO_QUERY_THROW);
uno::Reference<beans::XPropertySet> xSettings(
xFactory->createInstance(u"com.sun.star.document.Settings"_ustr), uno::UNO_QUERY_THROW);
CPPUNIT_ASSERT_EQUAL(uno::Any(true), xSettings->getPropertyValue(
- u"NoSpaceAfterHangingFootnoteNumbering"_ustr));
+ u"NoGapAfterNoteNumber"_ustr));
xmlDocUniquePtr pXmlDoc = parseLayoutDump();
sal_Int32 width
@@ -1276,14 +1275,14 @@ CPPUNIT_TEST_FIXTURE(Test, testTdf159382)
}
createSwDoc("footnote_spacing_hanging_para.rtf");
// 4. Make sure that RTF import sets NoSpaceAfterHangingFootnoteNumbering option, and creates
// correct layout
{
uno::Reference<lang::XMultiServiceFactory> xFactory(mxComponent, uno::UNO_QUERY_THROW);
uno::Reference<beans::XPropertySet> xSettings(
xFactory->createInstance(u"com.sun.star.document.Settings"_ustr), uno::UNO_QUERY_THROW);
CPPUNIT_ASSERT_EQUAL(uno::Any(true), xSettings->getPropertyValue(
- u"NoSpaceAfterHangingFootnoteNumbering"_ustr));
+ u"NoGapAfterNoteNumber"_ustr));
xmlDocUniquePtr pXmlDoc = parseLayoutDump();
sal_Int32 width
@@ -1302,7 +1301,7 @@ CPPUNIT_TEST_FIXTURE(Test, testTdf159382)
uno::Reference<beans::XPropertySet> xSettings(
xFactory->createInstance(u"com.sun.star.document.Settings"_ustr), uno::UNO_QUERY_THROW);
CPPUNIT_ASSERT_EQUAL(uno::Any(false), xSettings->getPropertyValue(
- u"NoSpaceAfterHangingFootnoteNumbering"_ustr));
+ u"NoGapAfterNoteNumber"_ustr));
}
}
@@ -1209,17 +1209,17 @@ CPPUNIT_TEST_FIXTURE(Test, testTdf150408_IsLegal)
createSwDoc("footnote_spacing_hanging_para.docx");
- // 1. Make sure that DOCX import sets NoSpaceAfterHangingFootnoteNumbering option, and creates
+ // 1. Make sure that DOCX import sets NoGapAfterNoteNumber option, and creates
// correct layout
{
@@ -1232,20 +1232,19 @@ CPPUNIT_TEST_FIXTURE(Test, testTdf159382)
}
saveAndReload(mpFilter);
- // 2. Make sure that exported document has NoSpaceAfterHangingFootnoteNumbering option set,
+ // 2. Make sure that exported document has NoGapAfterNoteNumber option set,
// and has correct layout
{
@@ -1256,14 +1255,14 @@ CPPUNIT_TEST_FIXTURE(Test, testTdf159382)
}
createSwDoc("footnote_spacing_hanging_para.doc");
- // 3. Make sure that DOC import sets NoSpaceAfterHangingFootnoteNumbering option, and creates
+ // 3. Make sure that DOC import sets NoGapAfterNoteNumber option, and creates
// correct layout
{
@@ -1276,14 +1275,14 @@ CPPUNIT_TEST_FIXTURE(Test, testTdf159382)
}
createSwDoc("footnote_spacing_hanging_para.rtf");
- // 4. Make sure that RTF import sets NoSpaceAfterHangingFootnoteNumbering option, and creates
+ // 4. Make sure that RTF import sets NoGapAfterNoteNumber option, and creates
// correct layout
{